==> libiodbc2_3.51.2.orig.tar.gz: libiodbc-3.51.2/iodbc/trace/Connect.c <==
/*
 *  Connect.c
 *
 *  $Id: Connect.c,v 1.2 2003/08/22 14:28:41 source Exp $
 *
 *  SQLConnect trace functions
 *
 *  The iODBC driver manager.
 *  
 *  Copyright (C) 1996-2003 by OpenLink Software <iodbc@openlinksw.com>
 *  All Rights Reserved.
 *
 *  This software is released under the terms of either of the following
 *  licenses:
 *
 *      - GNU Library General Public License (see LICENSE.LGPL) 
 *      - The BSD License (see LICENSE.BSD).
 *
 *  While not mandated by the BSD license, any patches you make to the
 *  iODBC source code may be contributed back into the iODBC project
 *  at your discretion. Contributions will benefit the Open Source and
 *  Data Access community as a whole. Submissions may be made at:
 *
 *      http://www.iodbc.org
 *
 *
 *  GNU Library Generic Public License Version 2
 *  ============================================
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *  The BSD License
 *  ===============
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *  3. Neither the name of OpenLink Software Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OPENLINK OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "trace.h"


void
trace_SQLConnect (int trace_leave, int retcode,
  SQLHDBC		  hdbc,
  SQLCHAR  		* szDSN,
  SQLSMALLINT		  cbDSN,
  SQLCHAR   		* szUID,
  SQLSMALLINT		  cbUID,
  SQLCHAR   		* szAuthStr,
  SQLSMALLINT		  cbAuthStr)
{
  /* Trace function */
  _trace_print_function (en_Connect, trace_leave, retcode);

  /* Trace Arguments */
  _trace_handle (SQL_HANDLE_DBC, hdbc);
  _trace_string (szDSN, cbDSN, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  _trace_string (szUID, cbUID, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  /* Hide plaintext passwords */
  _trace_string ((SQLCHAR *) "***", SQL_NTS, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbAuthStr);
}


void
trace_SQLConnectW (int trace_leave, int retcode,
  SQLHDBC		  hdbc,
  SQLWCHAR  		* szDSN,
  SQLSMALLINT		  cbDSN,
  SQLWCHAR  		* szUID,
  SQLSMALLINT		  cbUID,
  SQLWCHAR  		* szAuthStr,
  SQLSMALLINT		  cbAuthStr)
{
  /* Trace function */
  _trace_print_function (en_ConnectW, trace_leave, retcode);

  /* Trace Arguments */
  _trace_handle (SQL_HANDLE_DBC, hdbc);
  _trace_string_w (szDSN, cbDSN, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  _trace_string_w (szUID, cbUID, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  /* Hide plaintext passwords */
  _trace_string ((SQLCHAR *) "***", SQL_NTS, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbAuthStr);
}

==> libiodbc2_3.52.2.orig.tar.gz: libiodbc-3.52.2/iodbc/trace/Connect.c <==
/*
 *  Connect.c
 *
 *  $Id: Connect.c,v 1.3 2004/06/21 13:32:47 source Exp $
 *
 *  SQLConnect trace functions
 *
 *  The iODBC driver manager.
 *  
 *  Copyright (C) 1996-2003 by OpenLink Software <iodbc@openlinksw.com>
 *  All Rights Reserved.
 *
 *  This software is released under the terms of either of the following
 *  licenses:
 *
 *      - GNU Library General Public License (see LICENSE.LGPL) 
 *      - The BSD License (see LICENSE.BSD).
 *
 *  While not mandated by the BSD license, any patches you make to the
 *  iODBC source code may be contributed back into the iODBC project
 *  at your discretion. Contributions will benefit the Open Source and
 *  Data Access community as a whole. Submissions may be made at:
 *
 *      http://www.iodbc.org
 *
 *
 *  GNU Library Generic Public License Version 2
 *  ============================================
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 *  The BSD License
 *  ===============
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *  3. Neither the name of OpenLink Software Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OPENLINK OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "trace.h"


void
trace_SQLConnect (int trace_leave, int retcode,
  SQLHDBC		  hdbc,
  SQLCHAR  		* szDSN,
  SQLSMALLINT		  cbDSN,
  SQLCHAR   		* szUID,
  SQLSMALLINT		  cbUID,
  SQLCHAR   		* szAuthStr,
  SQLSMALLINT		  cbAuthStr)
{
  /* Trace function */
  _trace_print_function (en_Connect, trace_leave, retcode);

  /* Hide plaintext passwords */
  szAuthStr = (SQLCHAR *) "****";

  /* Trace Arguments */
  _trace_handle (SQL_HANDLE_DBC, hdbc);
  _trace_string (szDSN, cbDSN, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  _trace_string (szUID, cbUID, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  _trace_string (szAuthStr, SQL_NTS, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbAuthStr);
}


void
trace_SQLConnectW (int trace_leave, int retcode,
  SQLHDBC		  hdbc,
  SQLWCHAR  		* szDSN,
  SQLSMALLINT		  cbDSN,
  SQLWCHAR  		* szUID,
  SQLSMALLINT		  cbUID,
  SQLWCHAR  		* szAuthStr,
  SQLSMALLINT		  cbAuthStr)
{
  /* Trace function */
  _trace_print_function (en_ConnectW, trace_leave, retcode);

  /* Hide plaintext passwords */
  szAuthStr = (SQLWCHAR *) L"****";

  /* Trace Arguments */
  _trace_handle (SQL_HANDLE_DBC, hdbc);
  _trace_string_w (szDSN, cbDSN, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  _trace_string_w (szUID, cbUID, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbDSN);
  _trace_string_w (szAuthStr, SQL_NTS, NULL, TRACE_INPUT);
  _trace_stringlen ("SQLSMALLINT", cbAuthStr);
}
